@@ -15,7 +15,7 @@ from redis import Redis
 
 __all__ = ['HotQueue']
 
-__version__ = '0.2.6'
+__version__ = '0.2.7'
 
 
 def key_for_name(name):
@@ -33,18 +33,16 @@ class HotQueue(object):
     :param name: name of the queue
     :param serializer: the class or module to serialize msgs with, must have
         methods or functions named ``dumps`` and ``loads``,
-        `pickle <http://docs.python.org/library/pickle.html>`_ will be used
-        if ``None`` is given
+        `pickle <http://docs.python.org/library/pickle.html>`_ is the default,
+        use ``None`` to store messages in plain text (suitable for strings,
+        integers, etc)
     :param kwargs: additional kwargs to pass to :class:`Redis`, most commonly
         :attr:`host`, :attr:`port`, :attr:`db`
     """
     
-    def __init__(self, name, serializer=None, **kwargs):
+    def __init__(self, name, serializer=pickle, **kwargs):
         self.name = name
-        if serializer is not None:
-            self.serializer = serializer
-        else:
-            self.serializer = pickle
+        self.serializer = serializer
         self.__redis = Redis(**kwargs)
     
     def __len__(self):
@@ -62,7 +60,7 @@ class HotQueue(object):
     def consume(self, **kwargs):
         """Return a generator that yields whenever a message is waiting in the
         queue. Will block otherwise. Example:
-
+        
         >>> for msg in queue.consume(timeout=1):
         ...     print msg
         my message
@@ -102,23 +100,28 @@ class HotQueue(object):
                 msg = msg[1]
         else:
             msg = self.__redis.lpop(self.key)
-        if msg is not None:
+        if msg is not None and self.serializer is not None:
             msg = self.serializer.loads(msg)
         return msg
     
     def put(self, *msgs):
         """Put one or more messages onto the queue. Example:
-    
+        
         >>> queue.put("my message")
         >>> queue.put("another message")
+        
+        To put messages onto the queue in bulk, which can be significantly
+        faster if you have a large number of messages:
+        
+        >>> queue.put("my message", "another message", "third message")
         """
-        for msg in msgs:
-            msg = self.serializer.dumps(msg)
-            self.__redis.rpush(self.key, msg)
+        if self.serializer is not None:
+            msgs = map(self.serializer.dumps, msgs)
+        self.__redis.rpush(self.key, *msgs)
     
     def worker(self, *args, **kwargs):
         """Decorator for using a function as a queue worker. Example:
-    
+        
         >>> @queue.worker(timeout=1)
         ... def printer(msg):
         ...     print msg
